@@ -44,18 +44,27 @@ url = ''
 debug = 0
 # Variables - Deploy AWX
 
+# Variables - Change version
+arch_type = ''
+# Variables - Change version
+
+# Variables - Sync repository
+branch = ''
+commit_message = ''
+# Variables - sync repository
+
 
 def main(argv):  
     print("Copyright \N{COPYRIGHT SIGN} 2020 Stewartium ::: artify v{}\n".format(__version__))
     action = ''
     
-    ## Variables - Deploy AWX
+    # Variables - Deploy AWX
     global encoded_string 
     global url
     global debug
-    ## Variables - Deploy AWX
+    # Variables - Deploy AWX
     
-    ## Variables - Nexus
+    # Variables - Nexus
     global nexus_format 
     global artifact_name
     global work_directory
@@ -68,9 +77,16 @@ def main(argv):
     global directory
     global group_id
     global auth
-    ## Variables - Nexus
+    # Variables - Nexus
     
+    # Variables - Change version
+    global arch_type
+    global change_type
+    # Variables - Change version
     
+    global branch
+    global commit_message
+   
     try:
         opts, args = getopt.getopt(argv, "a:b:c:d:h:f:m:n:u:p:r:g:t:w:", ["command=", "help", 
                                                 "artifactname=", "repository=","groupid=", "directory=", "nexushost=",
@@ -130,7 +146,8 @@ def main(argv):
                 print("python -m artify --command deltav --type <version_change> --archtype <architecture_type>")
                 print("")
                 print("e.g --archtype npm, dotnet, springboot ")
-                print()
+                print("\nOptional arguments: ")
+                print("-b, --branch        Branch to commit code changes. Default: develop")
                 print("e.g --type major    1.0.0.0 => 2.0.0.0")
                 print("e.g --type minor    1.0.0.0 => 1.1.0.0")
                 print("e.g --type patch    1.0.0.0 => 1.0.1.0")
@@ -246,11 +263,10 @@ def main(argv):
         ## Change version (deltav) START
         elif opt in ("-t", "--type"):
             change_type = arg
-        elif opt in ("-a", "--archtype"):
-            arch_type = arg
+            
         ## Change version (deltav) END
         elif opt in ("-m", "--message"):
-                commit_message = arg
+            commit_message = arg
         elif opt in ("-b", "--branch"):
             branch = arg
         ## Commit-push changes repository START
